# Documentation

## [Getting started](getting_started.md)
- [Install from PyPI](getting_started.md#option-1-install-from-pypi)
- [Install from Git](getting_started.md#option-2-install-from-git)
- [Running Tests](getting_started.md#running-tests)
- [Running your first locality](getting_started.md#running-your-first-locality)
## [The basics](the_basics.md)
- [Creating a new locality](the_basics.md#creating-a-new-locality)
- [Code modules](the_basics.md#code-modules)
- [Jupyter Notebooks](the_basics.md#using-the-jupyter-notebooks)
- [Terminology](the_basics.md#terminology)
## [Configuration](config.md)
- [Cloud storage](config.md#configuring-cloud-storage)
- [PDF report generation](config.md#configuring-pdf-report-generation)
- [US Census API](config.md#configuring-census-api-access)
- [Open Street Map API](config.md#configuring-openstreetmap-enrichment)
